#include "mainwindow.h"
#include "ui_mainwindow.h"
#include "errordialog.h"
#include "errordialog2.h"
#include <QFileDialog>
#include <Qstring>
#include <QFile>
#include <QTextStream>
#include <QProcess>

//variable declarations
QString fileName;
QString filePath;
QString fileType;
QString handle;
QString summaryType;
int refresh;
int range;
int operation;
int graphTime;
int runTime;
int axisX;
int axisY;
bool graphViz;
bool run;
bool singlefile;

//take user input and compiles to in.put for Net Analyzer to read
void goInput()
{
    if(filePath == "")                          //if no file path has been specified
    {
        errordialog2 mDialog;
        mDialog.setModal(true);
        mDialog.exec();
    }
    else
    {
        QFile file("in.put");
        file.resize(0);                         //overwrites old input file so that there is no leftover input
        if(file.open(QIODevice::ReadWrite))
        {
            QTextStream stream(&file);
            stream << operation << endl << filePath << endl;
            switch(operation)
            {
            case 1:
                stream << refresh << endl << range << endl;
                if(run)
                    stream << "true" << endl;
                else
                    stream << "false" << endl;
                stream << fileType << endl;
                if(singlefile)
                    stream << "single" << endl;
                else
                    stream << "multiple" << endl;
                stream << runTime << endl << axisX << endl << axisY;
                break;
            case 2:
                stream << runTime << endl;
                if(graphViz)
                    stream << "true" << endl << graphTime << endl;
                else
                    stream << "false" << endl << "0" << endl;
                break;
            case 3:
                if(graphViz)
                    stream << "true" << endl;
                else
                    stream << "false" << endl;
                stream << range << endl << fileType << endl;
                if(singlefile)
                    stream << "single" << endl;
                else
                    stream << "multiple" << endl;
                break;
            case 4:
                stream << handle << endl << fileType << endl << summaryType << endl << runTime << endl;
                break;
            case 5:
                stream << handle << endl << summaryType << endl;
                break;
            }
            file.close();
            QProcess *myProcess = new QProcess();
            QStringList arguments;
            arguments << "in.put";
            QString program = ".\\NetAnalyzer.exe";
            myProcess->start(program, arguments);
        }
    }
}

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{
    ui->setupUi(this);
    setCentralWidget(ui->tabWidget);
}

MainWindow::~MainWindow()
{
    delete ui;
}
void MainWindow::on_pushButton_clicked()            //get a file for Location Generator
{
    filePath = QFileDialog::getOpenFileName(this, tr("Open File"), "", tr("Files (*.*)"));
    ui->lineEdit->setText(filePath);
    int test = filePath.lastIndexOf("/");
    filePath.chop(filePath.length()-test);
}

void MainWindow::on_pushButton_2_clicked()              //1 - Location Generator finished with input
{
    if(ui->radioButton->isChecked())                        //single file
    {
        filePath = ui->lineEdit->text();
        singlefile = true;
    }
    else                                                    //multiple files
    {
        filePath = ui->lineEdit_2->text();                  //gets the full folder path
        singlefile = false;
    }
    refresh = ui->spinBox_2->value();
    range = ui->spinBox->value();
    run = ui->checkBox_2->isChecked();
    operation = 1;
    int index = ui->comboBox_2->currentIndex();
    if(index == 0)
        fileType = ".txt";
    if(index == 1)
        fileType = ".xml";
    if(index == 2)
        fileType = ".imn";
    runTime = ui->spinBox_8->value();
    axisX = ui->spinBox_9->value();
    axisY = ui->spinBox_10->value();
    goInput();
}

void MainWindow::on_pushButton_6_clicked()              //2 - Dynamic Statistics finished with input
{
    filePath = ui->lineEdit_3->text();
    graphViz = ui->checkBox->isChecked();
    if(graphViz)
        graphTime = ui->spinBox_3->value();
    runTime = ui->spinBox_5->value();
    operation = 2;
    goInput();
}

void MainWindow::on_pushButton_5_clicked()
{
    filePath = QFileDialog::getOpenFileName(this, tr("Open File"), "", tr("Files (*.*)"));
    ui->lineEdit_3->setText(filePath);
}

void MainWindow::on_pushButton_7_clicked()
{
    filePath = QFileDialog::getOpenFileName(this, tr("Open File"), "", tr("Files (*.*)"));
    ui->lineEdit_4->setText(filePath);
}

void MainWindow::on_pushButton_8_clicked()              //3 - Static Statistics finished with input
{
    graphViz = ui->checkBox_3->isChecked();
    range = ui->spinBox_4->value();
    operation = 3;
    int index = ui->comboBox_4->currentIndex();
    if(index == 0)
        fileType = ".txt";
    if(index == 1)
        fileType = ".xml";
    if(index == 2)
        fileType = ".imn";
    if(ui->radioButton_5->isChecked())
    {
        singlefile = true;
        filePath = ui->lineEdit_4->text();
    }
    else
    {
        singlefile = false;
        filePath = ui->lineEdit_8->text();
    }
    goInput();
}

void MainWindow::on_pushButton_10_clicked()             //4 - Statistics Summary finished with input
{
    if(ui->lineEdit_7->text() == "")
    {
        ErrorDialog mDialog;
        mDialog.setModal(true);
        mDialog.exec();
    }
    else
    {
        filePath = ui->lineEdit_5->text();
        operation = 4;
        int index = ui->comboBox_3->currentIndex();
        if(index == 0)
            fileType = ".txt";
        if(index == 1)
            fileType = ".xml";
        if(index == 2)
            fileType = ".imn";
        handle = ui->lineEdit_7->text();
        runTime = ui->spinBox_6->value();
        if(ui->radioButton_3->isChecked())
            summaryType = "Dynamic";
        else
            summaryType = "Static";
        goInput();
    }
}

void MainWindow::on_pushButton_4_clicked()              //get a directory for Location Generator (multiple files)
{
    filePath = QFileDialog::getExistingDirectory(this, tr("Open Directory"), "/home", QFileDialog::ShowDirsOnly);
    ui->lineEdit_2->setText(filePath);
}

void MainWindow::on_pushButton_9_clicked()              //get a directory for Statistics Summary
{
    filePath = QFileDialog::getExistingDirectory(this, tr("Open Directory"), "/home", QFileDialog::ShowDirsOnly);
    ui->lineEdit_5->setText(filePath);
}

void MainWindow::on_pushButton_12_clicked()             //get a directory for Static Statistics (multiple files)
{
    filePath = QFileDialog::getExistingDirectory(this, tr("Open Directory"), "/home", QFileDialog::ShowDirsOnly);
    ui->lineEdit_8->setText(filePath);
}

void MainWindow::on_pushButton_13_clicked()
{
    filePath = QFileDialog::getExistingDirectory(this, tr("Open Directory"), "/home", QFileDialog::ShowDirsOnly);
    ui->lineEdit_9->setText(filePath);
}

void MainWindow::on_pushButton_14_clicked()             //5 - Spreadsheet Creation finished with input
{
    filePath = ui->lineEdit_9->text();
    if(ui->lineEdit_10->text() == "")
    {
        ErrorDialog mDialog;
        mDialog.setModal(true);
        mDialog.exec();
    }
    else
    {
        operation = 5;
        handle = ui->lineEdit_10->text();
        if(ui->radioButton_7->isChecked())
            summaryType = "Static";
        else
            summaryType = "Dynamic";
        goInput();
    }
}

void MainWindow::on_pushButton_11_clicked()
{
    filePath = QFileDialog::getOpenFileName(this, tr("Open File"), "", tr("Files (*.*)"));
    ui->lineEdit_6->setText(filePath);
}

void MainWindow::on_pushButton_15_clicked()
{
    filePath = ui->lineEdit_6->text();
    if(filePath == "")
    {
        errordialog2 mDialog;
        mDialog.setModal(true);
        mDialog.exec();
    }
    else
    {
        QProcess *myProcess = new QProcess();
        QStringList arguments;
        ui->lineEdit_11->setText(QString("animations_graphs(\'%1\',%2)").arg(filePath).arg(ui->spinBox_7->value()));
        arguments << QString("-r animations_graphs(\'%1\',%2);exit").arg(filePath).arg(ui->spinBox_7->value())  //this should automatically run animations_graphs with the correct parameters, however it doesn't in practice
                  << "-nodesktop" << "-nosplash";               //do not start the MATLAB desktop, do not show the splash screen
        QString program = "matlab";
        myProcess->start(program, arguments);
    }
}
